'Makes 2 changes to ParEd: Cmd-G inserts " := "  and Cmd-H searches for the selection.'!

!ParagraphEditor methodsFor: 'menu messages' stamp: 'stp 8/18/2000 16:54'!
find
	"Prompt the user for a string to search for, and search the receiver from the current selection onward for it."
	"Default selection is clipboard text."

	| reply |
	reply _ FillInTheBlank request: 'Find what? ' initialAnswer: self clipboardText.
	reply size == 0 ifTrue: [^ self].
	self setSearch: reply.
	ChangeText _ FindText.  "Implies no replacement to againOnce: method"
	self againOrSame: true! !

!ParagraphEditor methodsFor: 'menu messages' stamp: 'stp 8/18/2000 16:57'!
findSelection
	"Search the receiver from the current selection onward for the selection"

	| reply |
	reply := self selection string.
	reply size == 0 ifTrue: [^ self].
	self setSearch: reply.
	ChangeText _ FindText.
	self againOrSame: true! !

!ParagraphEditor methodsFor: 'typing/selecting keys' stamp: 'stp 8/18/2000 16:58'!
findSelection: characterStream
	"Find the next instance of the current selection text."

	sensor keyboard.		"flush character"
	self closeTypeIn: characterStream.
	self findSelection.
	^ true! !

!ParagraphEditor methodsFor: 'typing/selecting keys' stamp: 'mir 10/29/1999 18:33'!
displayAssignment: characterStream
        "Replace the current text selection with the text ':='--initiated by
        ctrl-g."

        sensor keyboard.                "flush character"
        characterStream nextPutAll: ' := '.
        ^false! !

!ParagraphEditor class methodsFor: 'class initialization' stamp: 'stp 8/18/2000 16:59'!
initializeTextEditorMenus   "ParagraphEditor initializeTextEditorMenus"
		"Initialize the yellow button pop-up menu and corresponding messages."

	TextEditorYellowButtonMenu _ SelectionMenu
		labels: 
'find...(f)
find again (g)
find selection (h)
do again (j)
undo (z)
copy (c)
cut (x)
paste (v)
paste...
do it (d)
print it (p)
inspect it (i)
accept (s)
cancel (l)
show bytecodes
more...' 
		lines: #(3 5 9 12 14 15)
		selections: #(find findAgain setSearchString again undo copySelection cut paste pasteRecent doIt printIt inspectIt accept cancel showBytecodes shiftedYellowButtonActivity)
! !

!ParagraphEditor class methodsFor: 'keyboard shortcut tables' stamp: 'stp 8/18/2000 16:59'!
initializeCmdKeyShortcuts
	"Initialize the (unshifted) command-key shortcut table."
	"NOTE: if you don't know what your keyboard generates, use Sensor kbdTest"
	"ParagraphEditor initialize"

	| cmdMap cmds |
	cmdMap _ Array new: 256 withAll: #noop:.  "use temp in case of a crash"
	cmdMap at: ( 1 + 1) put: #cursorHome:.			"home key"
	cmdMap at: ( 4 + 1) put: #cursorEnd:.			"end key"
	cmdMap at: ( 8 + 1) put: #backspace:.			"ctrl-H or delete key"
	cmdMap at: (11 + 1) put: #cursorPageUp:.			"page up key"
	cmdMap at: (12 + 1) put: #cursorPageDown:.		"page down key"
	cmdMap at: (13 + 1) put: #crWithIndent:.			"cmd-Return"
	cmdMap at: (27 + 1) put: #selectCurrentTypeIn:.	"escape key"
	cmdMap at: (28 + 1) put: #cursorLeft:.			"left arrow key"
	cmdMap at: (29 + 1) put: #cursorRight:.			"right arrow key"
	cmdMap at: (30 + 1) put: #cursorUp:.				"up arrow key"
	cmdMap at: (31 + 1) put: #cursorDown:.			"down arrow key"
	cmdMap at: (32 + 1) put: #selectWord:.			"space bar key"
	cmdMap at: (127 + 1) put: #forwardDelete:.		"del key"

	'0123456789-=' do: [ :char | cmdMap at: (char asciiValue + 1) put: #changeEmphasis: ].
	'([{''"<' do: [ :char | cmdMap at: (char asciiValue + 1) put: #enclose: ].
	cmdMap at: ($, asciiValue + 1) put: #shiftEnclose:.

	cmds _ #(
		$a	selectAll:
		$b	browseIt:
		$c	copySelection:
		$d	doIt:
		$e	exchange:
		$f	find:
		$g	displayAssignment:			"stp"
		$h	findSelection:				"stp"
		$i	inspectIt:
		$j	doAgainOnce:
		$k  offerFontMenu:
		$l	cancel:
		$m	implementorsOfIt:
		$n	sendersOfIt:
		$o	spawnIt:
		$p	printIt:
		$q	querySymbol:
		$r	recognizer:
		$s	save:
		$t	tempCommand:
		$u	findAgain:				"stp"
		$v	paste:
		$w	backWord:
		$x	cut:
		$y	swapChars:
		$z	undo:
	).
	1 to: cmds size by: 2 do: [ :i |
		cmdMap at: ((cmds at: i) asciiValue + 1) put: (cmds at: i + 1).
	].
	CmdActions _ cmdMap! !

ParagraphEditor initialize!
