'C-style string formatting. Takes this:

	Transcript cr; show: ''Analyze '', sound name,
		'' D: '', (duration printPlaces: 3), 
		'' R: '', sound rate printString,
		'' F: '', framesize printString, 
		'' P: '', npoles printString; cr.

and reduces it to this:

	{sound name. duration. sound rate. framesize. npoles} 
		showFmt: ''	Analyze %s D: %f R: %d F: %d P: %d''.	

Or this
		Transcript show: ''TSR: '', tsr printString, 
						'' e: '', e truncated printString; cr.

reduces to:

		{tsr . ext} showFmt: ''TSR: %s e: %d"

Try this:
	{ t0 / 1000 . nFrames * fftLen } showFmt: ''Took %5.2f sec, sz: %d.''
'!


!String methodsFor: 'converting' stamp: 'stp 8/19/2000 19:49'!
asFormatWith: valArray
	"Interpret the receiver as a C-style format string and fill it in using
	 the given value array; supports formats %d, %f, %s, %x with field 
	 width (%24s) and/or precision (%6.3f)"
	"Limitation: only handles 1-digit place; don't try %134.44f "

	"Examples (print these)"
	" 'V1: %d, V2: %f, V3: %x' asFormatWith: #(100 3.221645645643 255)"
	" 'V1: %16s, V2: %9.3f, V3: %8d hex.' asFormatWith: #('str1' 3.221645645643 255) "

	| strm out ind fld |
	ind := 1.
	strm _ ReadStream on: self.
	out _ WriteStream on: (String new: self size * 2).
	[	| sel val wid pre |
		out nextPutAll: (strm upTo: $%).		"copy up to first %"
		strm atEnd ifTrue: [^out contents].
		wid := nil.
		pre := 4.			"default decimal precision"
		sel := strm next.		"read char after %"
		[sel isDigit]			"if number format like  %12d"
			whileTrue: [wid ifNil: [wid := 0].
					wid := (wid * 10) + sel digitValue.
					sel := strm next].
		(sel == $.)			"if like %5.3f"
			ifTrue: [pre := strm next digitValue.
					sel := strm next].
		val := valArray at: (ind min: valArray size).
							"case statement to print value"
		fld := (		($d -> [val truncated printString]),
					($f -> [val asFloat printPlaces: pre]),
					($s -> [val]),
					($x -> [val printStringBase: 16]))
				case: sel otherwise: '?'.
		wid ifNotNil:		"pad field if necessary"
			[(fld size < wid) 
				ifTrue: [out nextPutAll: (String new: (wid - fld size))]].
		out nextPutAll: fld.		"write value"
		ind := ind + 1.
		true] whileTrue! !


!TranscriptStream methodsFor: 'stream extensions' stamp: 'stp 8/23/2000 16:25'!
showTab: vArray fmt: fmtStr
	"Formatted transcript print-on with CR; see String asFormatWith:"
	"Transcript showTab: #('str1' 3.221645645643 255)
				fmt: 'V1: %s, V2: %f, V3: %x'"

	self nextPutAll: (fmtStr asFormatWith: vArray); tab; endEntry! !

!TranscriptStream methodsFor: 'stream extensions' stamp: 'stp 8/23/2000 16:25'!
show: vArray fmt: fmtStr
	"Formatted transcript print-on with CR; see String asFormatWith:"
	"Transcript show: #('str1' 3.221645645643 255)
				fmt: 'V1: %s, V2: %f, V3: %x'"

	self nextPutAll: (fmtStr asFormatWith: vArray); endEntry! !

!TranscriptStream methodsFor: 'stream extensions' stamp: 'stp 8/23/2000 16:25'!
showCr: vArray fmt: fmtStr
	"Formatted transcript print-on with CR; see String asFormatWith:"
	"Transcript showCr: #('str1' 3.221645645643 255)
				fmt: 'V1: %s, V2: %f, V3: %x'"

	self nextPutAll: (fmtStr asFormatWith: vArray); cr; endEntry! !

!SequenceableCollection methodsFor: 'printing' stamp: 'stp 8/20/2000 19:15'!
showFmt: fmtString
	"Show the elements of the receiver on the Transcript using the given C-style string."
	" #('str1' 3.221645645643 255) showFmt: 'V1: %s, V2: %f, V3: %x' "

	Transcript show: self fmt: fmtString! !


!SequenceableCollection methodsFor: 'printing' stamp: 'stp 8/23/2000 16:28'!
showFmtCr: fmtString
	"Show the elements of the receiver on the Transcript using the given C-style string."
	" #('str1' 3.221645645643 255) showFmtCr: 'V1: %s, V2: %f, V3: %x' "

	Transcript showCr: self fmt: fmtString! !

!SequenceableCollection methodsFor: 'printing' stamp: 'stp 8/23/2000 16:27'!
showFmtTab: fmtString
	"Show the elements of the receiver on the Transcript using the given C-style string."
	" #('str1' 3.221645645643 255) showFmtTab: 'V1: %s, V2: %f, V3: %x' "

	Transcript showTab: self fmt: fmtString! !
